==> panvimwiki-0.8.0.tar.gz: panvimwiki-0.8.0/tests/func/convert_shift.md <==
## Journal 2017-04-24 {#Journal 2017-04-24}

### Ordered List {#Ordered List}

1.  []{.done4}OrderedList done4 should appear
    []{#-InlineTagShouldAppear}[InlineTagShouldAppear]{#InlineTagShouldAppear
    .tag} Continuation should appear\--avoid hard wrap!
2.  []{.done1}OrderedList done1 should appear
    1.  []{.done1}OrderedList a) done1 should appear
3.  []{.done2}OrderedList done2 should appear
4.  []{.done3}OrderedList done3 should appear
5.  \[-\] OrderedList doneX should appear
6.  OrderedList should appear
    1.  OrderedList a) should appear

#### Definition List {#Definition List}

Term 1
:   Definition 1 should appear

Term 2
:   should appear
:   Definition 2 should appear
:   Definition 3 should appear

#### Unordered lists {#Unordered lists}

-   Bulleted list item 1 should appear
-   Bulleted list item 1 should appear
    []{#-InlineTagShouldAppear}[InlineTagShouldAppear]{#InlineTagShouldAppear
    .tag}
    []{#-InlineTagShouldAppear}[InlineTagShouldAppear]{#InlineTagShouldAppear
    .tag}
-   Bulleted list item 2 should appear
-   []{.done1}Bulleted list item 4 should appear
-   []{.done1}Bulleted list item 4 should appear #1039a766
-   []{.done1}Bulleted list item 2 should convert to \[.\] done1
    #0b87d634
-   []{.done4}Bulleted list done4 item 4 should appear #f28405d6

Del_empty_heading will remove the following, but del_taskwiki_heading
will only remove the taskwiki heading:

#### Text {#Text}

Normal text should appear with only one blank line preceding next
heading.

### Empty Parent Heading with Non-Empty Child should appear {#Empty Parent Heading with Non-Empty Child should appear}

#### Non-Empty Child Heading should appear {#Non-Empty Child Heading should appear}

Non-Empty Child text should appear.

## Journal 2017-04-26 {#Journal 2017-04-26}

Should concatenate non-contiguous Monday and Wednesday and ignore
missing Tuesday and Thursday. Spurious not for test validation.

==> panvimwiki-0.10.1.tar.gz: panvimwiki-0.10.1/tests/func/convert_shift.md <==
## Journal 2017-04-24

### Ordered List

1.  []{.done4}OrderedList done4 should appear
    []{#-InlineTagShouldAppear}[InlineTagShouldAppear]{#InlineTagShouldAppear
    .tag} Continuation should appear\--avoid hard wrap!
2.  []{.done1}OrderedList done1 should appear
    1.  []{.done1}OrderedList a) done1 should appear
3.  []{.done2}OrderedList done2 should appear
4.  []{.done3}OrderedList done3 should appear
5.  \[-\] OrderedList doneX should appear
6.  OrderedList should appear
    1.  OrderedList a) should appear

#### Definition List

Term 1
:   Definition 1 should appear

Term 2
:   should appear
:   Definition 2 should appear
:   Definition 3 should appear

#### Unordered lists

-   Bulleted list item 1 should appear
-   Bulleted list item 1 should appear
    []{#-InlineTagShouldAppear}[InlineTagShouldAppear]{#InlineTagShouldAppear
    .tag}
    []{#-InlineTagShouldAppear}[InlineTagShouldAppear]{#InlineTagShouldAppear
    .tag}
-   Bulleted list item 2 should appear
-   []{.done1}Bulleted list item 4 should appear
-   []{.done1}Bulleted list item 4 should appear #1039a766
-   []{.done1}Bulleted list item 2 should convert to \[.\] done1
    #0b87d634
-   []{.done4}Bulleted list done4 item 4 should appear #f28405d6

Del_empty_heading will remove the following, but del_taskwiki_heading
will only remove the taskwiki heading:

#### Text

Normal text should appear with only one blank line preceding next
heading.

### Empty Parent Heading with Non-Empty Child should appear

#### Non-Empty Child Heading should appear

Non-Empty Child text should appear.

## Journal 2017-04-26

Should concatenate non-contiguous Monday and Wednesday and ignore
missing Tuesday and Thursday. Spurious not for test validation.
